@@ -1,4 +1,5 @@
 import re
+import codecs
 """
 Taken from https://gist.github.com/gilsondev/7c1d2d753ddb522e7bc22511cfb08676
 and modified for better output of tables.
@@ -80,7 +81,22 @@ PATTERN = re.compile(
 )
 
 
-def rtf_to_text(text):
+def rtf_to_text(text, errors="strict"):
+    """ Converts the rtf text to plain text.
+
+    Parameters
+    ----------
+    text : str
+        The rtf text
+    errors : str
+        How to handle encoding errors. Default is "strict", which throws an error. Another
+        option is "ignore" which, as the name says, ignores encoding errors.
+
+    Returns
+    -------
+    str
+        the converted rtf text as plain text
+    """
     stack = []
     ignorable = False  # Whether this group (and all inside it) are "ignorable".
     ucskip = 1  # Number of ASCII characters to skip after a unicode character.
@@ -89,7 +105,7 @@ def rtf_to_text(text):
     encoding = 'utf8'
 
     for match in PATTERN.finditer(text):
-        word, arg, hex, char, brace, tchar = match.groups()
+        word, arg, _hex, char, brace, tchar = match.groups()
         if brace:
             curskip = 0
             if brace == "{":
@@ -112,7 +128,10 @@ def rtf_to_text(text):
                     out = out + b"\xA0"  # NBSP
             elif char in "{}\\":
                 if not ignorable:
-                    out.append(char)
+                    if isinstance(out, bytes):
+                        out = out + char.encode(encoding, errors)
+                    else:
+                        out.append(char)
             elif char == "*":
                 ignorable = True
             elif char == "\n":
@@ -125,15 +144,19 @@ def rtf_to_text(text):
             curskip = 0
             if word in destinations:
                 ignorable = True
-
             # http://www.biblioscape.com/rtf15_spec.htm#Heading8
             elif word == "ansicpg":
                 encoding = f"cp{arg}"
-            
-            elif ignorable:
+                print(f"Got encoding {encoding}")
+                try:
+                    codecs.lookup(encoding)
+                except LookupError:
+                    print(f"Warning: Encoding {encoding} not found, using utf-8")
+                    encoding = "utf8"
+            if ignorable:
                 pass
             elif word in specialchars:
-                out = out + specialchars[word].encode(encoding)
+                out = out + specialchars[word].encode(encoding, errors)
             elif word == "uc":
                 ucskip = int(arg)
             elif word == "u":
@@ -144,18 +167,17 @@ def rtf_to_text(text):
                     c = int(arg)
                     if c < 0:
                         c += 0x10000
-                    out = out + chr(c).encode(encoding)
+                    out = out + chr(c).encode(encoding, errors)
                     curskip = ucskip
-        elif hex:  # \'xx
+        elif _hex:  # \'xx
             if curskip > 0:
                 curskip -= 1
             elif not ignorable:
-                c = int(hex, 16)
-                out = out + bytes.fromhex(hex)
+                c = int(_hex, 16)
+                out = out + bytes.fromhex(_hex)
         elif tchar:
             if curskip > 0:
                 curskip -= 1
             elif not ignorable:
-                out = out + tchar.encode(encoding)
-
-    return out.decode(encoding)
+                out = out + tchar.encode(encoding, errors)
+    return out.decode(encoding, errors)
